@@ -1,6 +1,13 @@
+// Copyright 2018 Stefan Kroboth
+//
+// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
+// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
+// http://opensource.org/licenses/MIT>, at your option. This file may not be
+// copied, modified, or distributed except according to those terms.
+
 //! Storage for persistently saving return values of functions on disk.
 use std::error::Error;
-use std::fs::{File, create_dir_all, remove_file, read_dir};
+use std::fs::{create_dir_all, read_dir, remove_file, File};
 use std::io::prelude::*;
 use std::path::Path;
 use regex::Regex;
@@ -11,15 +18,13 @@ use errors::*;
 use PREFIX;
 use PersistentCache;
 
-
 /// `FileStorage` struct
-// pub struct FileStorage<'a> {
 pub struct FileStorage {
+    /// Indicates where files are saved
     path: String,
 }
 
 impl FileStorage {
-    // impl<'a> FileStorage<'a> {
     /// Creates the `path` directory and returns a `FileStorage` struct.
     ///
     /// # Examples
@@ -32,11 +37,12 @@ impl FileStorage {
     // pub fn new(path: &'a str) -> Result<Self, Box<Error>> {
     pub fn new(path: &str) -> Result<Self> {
         create_dir_all(path)?;
-        Ok(FileStorage { path: path.to_owned() })
+        Ok(FileStorage {
+            path: path.to_owned(),
+        })
     }
 }
 
-// impl<'a> PersistentCache for FileStorage<'a> {
 impl PersistentCache for FileStorage {
     /// Returns the value corresponding to the variable `name`.
     fn get(&self, name: &str) -> Result<Vec<u8>> {
